==> jun1_24.zip: zad2_b.php <==
<?php
    echo var_dump($_POST['artikl']);
    $str = implode(" ", $_POST['artikl']);
    
?>
<!DOCTYPE html>
<html>
    <head>
        <meta http-equiv="Content-Type" content="text/html;charset=UTF-8">
        <style>
            *{
                box-sizing: border-box;
                color:coral;
            }
            form {
                width: 500px;
                height: 600px;
                margin: auto;
                position: relative;
                top: 100px;
                background-color: rgb(213, 246, 233);
                padding-left: 10px;
                padding-top: 10px;
            }
            img {
                width: 150px;
                height: 150px;
            }
            table{
                text-align: center;
            }
            input[type="submit"]{
                width: 150px;
                background-color: rgb(248, 236, 200);
                padding: 5px;
            }
        </style>
    </head>
    <body>
        
        <form action="zad2_c.php" method="POST">
            <h1>Podaci o kupcu</h1>
            <label for="Ime">Unesite ime:</label><br>
            <input type="text" name="ime" id="Ime"><br><br>
            <label for="prezime">Unesite prezime:</label><br>
            <input type="text" name="prezime" id="prezime"><br><br>
            <label for="adresa">Unesite adresu:</label><br>
            <input type="text" name="adresa" id="adresa"><br><br>
            <label for="mesto">Unesite mesto:</label><br>
            <input type="text" name="mesto" id="mesto"><br><br>
            <label for="posta">Unesti postanski broj:</label><br>
            <input type="text" name="posta" id="posta"><br><br>
            <label for="telefon">Unesite broj telefona:</label><br>
            <input type="text" name="telefon" id="telefon"><br><br>
            <input type="text" name="artikli" value="<?php echo $str;?>" hidden>

            <input type="submit" value="Potvrdi">
        </form>
    </body>
</html>

==> jun2_24.zip: zad2_b.php <==
<?php
    $solja = implode(" ", $_POST['odeca']);
    $boja = implode(" ", $_POST['boja']);
?>
<!DOCTYPE html>
<html>
    <head>
        <meta http-equiv="Content-Type" content="text/html;charset=UTF-8">
        <style>
            *{
                box-sizing: border-box;
                color:coral;
            }
            form {
                width: 500px;
                height: 600px;
                margin: auto;
                position: relative;
                top: 100px;
                background-color: rgb(213, 246, 233);
                padding-left: 10px;
                padding-top: 10px;
            }
            img {
                width: 150px;
                height: 150px;
            }
            table{
                text-align: center;
            }
            input[type="submit"]{
                width: 150px;
                background-color: rgb(248, 236, 200);
                padding: 5px;
            }
        </style>
    </head>
    <body>
        
        <form action="zad2_c.php" method="POST">
            <h1>Podaci o kupcu</h1>
            <label for="Ime">Unesite ime:</label><br>
            <input type="text" name="ime" id="Ime"><br><br>
            <label for="prezime">Unesite prezime:</label><br>
            <input type="text" name="prezime" id="prezime"><br><br>
            <label for="adresa">Unesite adresu:</label><br>
            <input type="text" name="adresa" id="adresa"><br><br>
            <label for="mesto">Unesite mesto:</label><br>
            <input type="text" name="mesto" id="mesto"><br><br>
            <label for="posta">Unesti postanski broj:</label><br>
            <input type="text" name="posta" id="posta"><br><br>
            <label for="telefon">Unesite broj telefona:</label><br>
            <input type="text" name="telefon" id="telefon"><br><br>
            <input type="text" name="solja" value="<?php echo $solja;?>" hidden>
            <input type="text" name="boja" value="<?php echo $boja;?>" hidden>

            <input type="submit" value="Potvrdi">
        </form>
    </body>
</html>
